==> tf_encrypted-0.4.0-py3-none-manylinux1_x86_64.whl: tf_encrypted/__init__.py <==
from __future__ import absolute_import
from typing import Optional, Any
import inspect
import tensorflow as tf

from .config import Config, LocalConfig, RemoteConfig, get_config
from .session import Session, setTFEDebugFlag, setMonitorStatsFlag, setTFETraceFlag
from .protocol import global_caches_updater, Pond, get_protocol
from .player import player
from . import protocol
from . import layers
from . import convert
from . import operations

all_prot_funcs = protocol.get_all_funcs()


def _prot_func_not_implemented(*args: Any, **kwargs: Any) -> None:
    raise Exception(
        "This function is not implemented in protocol {}".format(inspect.stack()[1][3])
    )


def _get_protocol_public_func(prot: protocol.Protocol) -> list:
    methods = inspect.getmembers(prot, predicate=inspect.ismethod)
    public_prot_methods = [method for method in methods if method[0][0] is not "_"]

    return public_prot_methods


def set_protocol(prot: Optional[protocol.Protocol] = None) -> None:
    """
    Sets the global protocol.  See :class:`~tensorflow_encrypted.protocol.protocol.Protocol` for
    more info.

    :param ~tensorflow_encrypted.protocol.protocol.Protocol prot: A protocol instance.
    """
    for func in all_prot_funcs:
        if func[0] in globals():
            del globals()[func[0]]

    protocol.set_protocol(prot)

    if prot is not None:
        funcs = _get_protocol_public_func(prot)

        for func in funcs:
            globals()[func[0]] = func[1]

    for func in all_prot_funcs:
        if func[0] not in globals():
            globals()[func[0]] = _prot_func_not_implemented


def set_config(config: Config) -> None:
    from .config import set_config as set_global_config

    set_global_config(config)
    set_protocol(None)


def global_variables_initializer() -> Optional[tf.Operation]:
    prot = protocol.get_protocol()
    if prot is not None:
        return prot.initializer
    else:
        return None


set_protocol(Pond())

__all__ = [
    "LocalConfig",
    "RemoteConfig",
    "setMonitorStatsFlag",
    "setTFETraceFlag",
    "setTFEDebugFlag",
    "get_config",
    "set_config",
    "get_protocol",
    "set_protocol",
    "Session",
    "io",
    "player",
    "protocol",
    "layers",
    "convert",
    "operations",
    "global_caches_updater",
    "global_variables_initializer",
]

==> tf_encrypted-0.5.2rc1-py3-none-manylinux1_x86_64.whl: tf_encrypted/__init__.py <==
from __future__ import absolute_import
from typing import Optional, Any
import inspect
import tensorflow as tf

from .config import Config, LocalConfig, RemoteConfig, get_config
from .player import player
from .protocol import global_caches_updater, Pond, get_protocol
from .session import Session, setTFEDebugFlag, setMonitorStatsFlag, setTFETraceFlag
from . import convert
from . import layers
from . import operations
from . import protocol


_all_prot_funcs = protocol.get_all_funcs()


def _prot_func_not_implemented(*args: Any, **kwargs: Any) -> None:
    raise Exception(
        "This function is not implemented in protocol {}".format(inspect.stack()[1][3])
    )


def set_protocol(prot: Optional[protocol.Protocol] = None) -> None:
    """
    Sets the global protocol. See :class:`~tf_encrypted.protocol.protocol.Protocol` for
    more info.

    :param ~tf_encrypted.protocol.protocol.Protocol prot: A protocol instance.
    """

    # reset all names
    for func_name in _all_prot_funcs:
        globals()[func_name] = _prot_func_not_implemented

    # add global names according to new protocol
    if prot is not None:
        methods = inspect.getmembers(prot, predicate=inspect.ismethod)
        public_methods = [method for method in methods if not method[0].startswith('_')]
        for name, func in public_methods:
            globals()[name] = func

    # record new protocol
    protocol.set_protocol(prot)


def set_config(config: Config) -> None:
    from .config import set_config as set_global_config

    set_global_config(config)
    set_protocol(None)


def global_variables_initializer() -> Optional[tf.Operation]:
    prot = protocol.get_protocol()
    if prot is not None:
        return prot.initializer
    else:
        return None


set_protocol(Pond())


__all__ = [
    "LocalConfig",
    "RemoteConfig",
    "setMonitorStatsFlag",
    "setTFETraceFlag",
    "setTFEDebugFlag",
    "get_config",
    "set_config",
    "get_protocol",
    "set_protocol",
    "Session",
    "io",
    "player",
    "protocol",
    "layers",
    "convert",
    "operations",
    "global_caches_updater",
    "global_variables_initializer",
]
